@@ -2,7 +2,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2021 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,12 +25,25 @@ Launcher
 import os
 import sys
 
+
 if 'posix' == os.name:
     if os.path.isdir('/usr/share/bleachbit'):
         # This path contains bleachbit/{C,G}LI.py .  This section is
         # unnecessary if installing BleachBit in site-packages.
         sys.path.append('/usr/share/')
 
+    # The two imports from bleachbit must come after sys.path.append(..)
+    import bleachbit.Unix
+    from bleachbit import _
+
+    if (
+        bleachbit.Unix.is_display_protocol_wayland_and_root_not_allowed()
+    ):
+        print(_('To run a GUI application on Wayland with root, allow access with this command:\n'
+              'xhost si:localuser:root\n'
+                'See more about xhost at https://docs.bleachbit.org/doc/frequently-asked-questions.html'))
+        sys.exit(1)
+
 if os.name == 'nt':
     # change error handling to avoid popup with GTK 3
     # https://github.com/bleachbit/bleachbit/issues/651
