@@ -2,7 +2,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2023 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -126,6 +126,7 @@ class Bleachbit(Gtk.Application):
         application_id = '{}{}'.format('org.gnome.Bleachbit', application_id_suffix)
         Gtk.Application.__init__(
             self, application_id=application_id, flags=Gio.ApplicationFlags.FLAGS_NONE)
+        GLib.set_prgname('org.bleachbit.BleachBit')
         GObject.threads_init()
 
         if auto_exit:
@@ -302,7 +303,7 @@ class Bleachbit(Gtk.Application):
 
     def get_about_dialog(self):
         dialog = Gtk.AboutDialog(comments=_("Program to clean unnecessary files"),
-                                 copyright='Copyright (C) 2008-2023 Andrew Ziem',
+                                 copyright='Copyright (C) 2008-2024 Andrew Ziem',
                                  program_name=APP_NAME,
                                  version=bleachbit.APP_VERSION,
                                  website=bleachbit.APP_URL,
@@ -871,7 +872,7 @@ class GUI(Gtk.ApplicationWindow):
             # http://bleachbit.sourceforge.net/forum/074-fails-errors
             try:
                 import sqlite3
-            except ImportError as e:
+            except ImportError:
                 self.append_text(
                     _("Error loading the SQLite module: the antivirus software may be blocking it."), 'error')
 
@@ -986,7 +987,7 @@ class GUI(Gtk.ApplicationWindow):
         treepath = Gtk.TreePath(0)
         try:
             __iter = model.get_iter(treepath)
-        except ValueError as e:
+        except ValueError:
             logger.warning(
                 'ValueError in get_iter() when updating file size for tree path=%s' % treepath)
             return
