@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2023 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -30,9 +30,9 @@ import sys
 import platform
 
 from bleachbit import Log
-from configparser import RawConfigParser, NoOptionError
+from configparser import RawConfigParser, NoOptionError # used in other files
 
-APP_VERSION = "4.6.0"
+APP_VERSION = "4.6.2"
 APP_NAME = "BleachBit"
 APP_URL = "https://www.bleachbit.org"
 
