@@ -2,7 +2,7 @@
 # coding=utf-8
 
 # BleachBit
-# Copyright (C) 2008-2021 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -24,11 +24,12 @@ Test case for module Cleaner
 """
 
 import logging
-import unittest
+import os
+import glob
 from xml.dom.minidom import parseString
 
 from bleachbit.Action import ActionProvider
-from bleachbit.Cleaner import *
+from bleachbit.Cleaner import Cleaner, backends, create_simple_cleaner, register_cleaners
 
 from tests import common
 
@@ -176,24 +177,26 @@ class CleanerTestCase(common.BleachbitTestCase):
         _iglob = glob.iglob
         _lexists = os.path.lexists
         _oswalk = os.walk
-        glob.iglob = lambda path: []
-        os.path.exists = lambda path: False
-        os.path.lexists = lambda path: False
-        os.walk = lambda top, topdown = True, onerror = None, followlinks = False: []
-        for key in sorted(backends):
-            for (option_id, __name) in backends[key].get_options():
-                for cmd in backends[key].get_commands(option_id):
-                    for result in cmd.execute(really_delete=False):
-                        if result != True:
-                            break
-                        msg = "Expected no files to be deleted but got '%s'" % str(
-                            result)
-                        self.assertNotIsInstance(cmd, Command.Delete, msg)
-                        common.validate_result(self, result)
-        glob.iglob = _iglob
-        os.path.exists = _exists
-        os.path.lexists = _lexists
-        os.walk = _oswalk
+        try:
+            glob.iglob = lambda path, root_dir=None, dir_fd=None, recursive=False: []
+            os.path.exists = lambda path: False
+            os.path.lexists = lambda path: False
+            os.walk = lambda top, topdown = True, onerror = None, followlinks = False: []
+            for key in sorted(backends):
+                for (option_id, __name) in backends[key].get_options():
+                    for cmd in backends[key].get_commands(option_id):
+                        for result in cmd.execute(really_delete=False):
+                            if result != True:
+                                break
+                            msg = "Expected no files to be deleted but got '%s'" % str(
+                                result)
+                            self.assertNotIsInstance(cmd, Command.Delete, msg)
+                            common.validate_result(self, result)
+        finally:
+            glob.iglob = _iglob
+            os.path.exists = _exists
+            os.path.lexists = _lexists
+            os.walk = _oswalk
 
     def test_register_cleaners(self):
         """Unit test for register_cleaners"""
@@ -204,6 +207,7 @@ class CleanerTestCase(common.BleachbitTestCase):
     @common.skipUnlessDestructive
     def test_system_recent_documents(self):
         """Clean recent documents in GTK"""
+        import Gtk
         mgr = Gtk.RecentManager().get_default()
         fn = self.mkstemp(suffix='.txt')
         self.assertExists(fn)
@@ -258,7 +262,6 @@ class CleanerTestCase(common.BleachbitTestCase):
             os.makedirs(obexd_dir)
         obexd_fn = os.path.join(obexd_dir, 'bleachbit-test')
         common.touch_file(obexd_fn)
-        found_canary = False
         for cmd in backends['system'].get_commands('cache'):
             for _result in cmd.execute(really_delete=False):
                 self.assertNotEqual(cmd.path, obexd_fn)
