@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2023 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -27,7 +27,7 @@ Test case for application level functions
 import os
 import sys
 import subprocess
-from unittest import mock, SkipTest
+from unittest import mock
 
 try:
     import gi
@@ -165,4 +165,4 @@ class ExternalCommandTestCase(common.BleachbitTestCase):
 
         if environment_changed:
             # We don't want to affect other tests, executed after this one.
-            common.put_env('BLEACHBIT_TEST_OPTIONS_DIR', None)
\ No newline at end of file
+            common.put_env('BLEACHBIT_TEST_OPTIONS_DIR', None)
