@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2023 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -23,14 +23,50 @@
 Test case for module FileUtilities
 """
 
-from tests import common
-from bleachbit.FileUtilities import *
-from bleachbit.General import run_external, sudo_mode
+
+from bleachbit.FileUtilities import (
+    bytes_to_human,
+    children_in_directory,
+    clean_ini,
+    clean_json,
+    delete,
+    detect_encoding,
+    ego_owner,
+    exists_in_path,
+    exe_exists,
+    expand_glob_join,
+    extended_path,
+    extended_path_undo,
+    free_space,
+    getsize,
+    getsizedir,
+    globex,
+    guess_overwrite_paths,
+    human_to_bytes,
+    is_dir_empty,
+    listdir,
+    open_files_lsof,
+    OpenFiles,
+    same_partition,
+    uris_to_paths,
+    vacuum_sqlite3,
+    whitelisted,
+    wipe_contents,
+    wipe_name,
+    wipe_path
+)
+from bleachbit.General import run_external
 from bleachbit.Options import options
 from bleachbit import logger
+from tests import common
 
 import json
+import locale
+import os
+import subprocess
 import sys
+import tempfile
+import time
 import unittest
 
 
@@ -513,7 +549,7 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
         if 'posix' == os.name:
             expand_glob_join('/bin', '*sh')
         if 'nt' == os.name:
-            expand_glob_join('c:\windows', '*.exe')
+            expand_glob_join(r'c:\windows', '*.exe')
 
     def test_expandvars(self):
         """Unit test for expandvars()."""
@@ -559,9 +595,9 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
         import re
         for line in stdout.split('\n'):
             line = line.strip()
-            if not re.match('([A-Z]):\s+(\d+)', line):
+            if not re.match(r'([A-Z]):\s+(\d+)', line):
                 continue
-            drive, bytes_free = re.split('\s+', line)
+            drive, bytes_free = re.split(r'\s+', line)
             print('Checking free space for %s' % drive)
             bytes_free = int(bytes_free)
             free = free_space(drive)
@@ -833,8 +869,8 @@ class FileUtilitiesTestCase(common.BleachbitTestCase):
         d = '/usr/bin'
         whitelist = [('file', '/home/foo'), ('folder', '/home/folder')]
         if 'nt' == os.name:
-            d = os.path.expandvars('%windir%\system32')
-            whitelist = [('file', r'c:\\filename'), ('folder', r'c:\\folder')]
+            d = os.path.expandvars(r'%windir%\system32')
+            whitelist = [('file', r'c:\filename'), ('folder', r'c:\\folder')]
         reps = 20
         paths = [p for p in children_in_directory(d, True)]
         paths = paths[:1000]  # truncate
