@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2023 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -205,7 +205,7 @@ root               531   0.0  0.0  2501712    588   ??  Ss   20May16   0:02.40 s
         configxml = '<path directoryregex="^.*$">' \
                     '  <path directoryregex="^(locale|dummyfiles)$">' \
                     '    <path location="." filter="*" />' \
-                    '    <regexfilter postfix="\.txt" />' \
+                    r'    <regexfilter postfix="\.txt" />' \
                     '  </path>' \
                     '</path>'
         from xml.dom.minidom import parseString
@@ -311,25 +311,68 @@ root               531   0.0  0.0  2501712    588   ??  Ss   20May16   0:02.40 s
         self.assertEqual(bytes_freed, 299000000)
 
     @common.skipIfWindows
-    def test_is_linux_display_protocol_wayland(self):
+    def test_is_unix_display_protocol_wayland_no_mock(self):
+        """Unit test for test_is_unix_display_protocol_wayland() with no mock"""
+        ret = is_unix_display_protocol_wayland()
+        self.assertIsInstance(ret, bool)
+
+    @common.skipIfWindows
+    def test_is_unix_display_protocol_wayland_mock_env(self):
+        """Unit test for test_is_unix_display_protocol_wayland() by mocking os.environ"""
+        # The environment variables take precedence.
+        with mock.patch.dict('os.environ', {'XDG_SESSION_TYPE': 'x11'}, clear=True):
+            self.assertFalse(is_unix_display_protocol_wayland())
+        with mock.patch.dict('os.environ', {'XDG_SESSION_TYPE': 'wayland'}, clear=True):
+            self.assertTrue(is_unix_display_protocol_wayland())
+        with mock.patch.dict('os.environ', {'WAYLAND_DISPLAY': 'yes'}, clear=True):
+            self.assertTrue(is_unix_display_protocol_wayland())
+
+    @common.skipIfWindows
+    @mock.patch.dict(os.environ, {}, clear=True)
+    def test_is_unix_display_protocol_wayland_mock_no_env(self):
+        """Unit test for test_is_unix_display_protocol_wayland() by clearing os.environ"""
+        self.assertEqual(len(os.environ), 0)
+
+        # Check that it does not throw an exception.
+        no_exception = is_unix_display_protocol_wayland()
+
         display_protocol = None
+
         def side_effect_func(value):
             if len(value) == 1:
                 return (0, 'SESSION  UID USER   SEAT  TTY \n      2 1000 debian seat0 tty2\n\n1 sessions listed.\n', '')
             elif len(value) > 1:
                 return (0, 'Type={}\n'.format(display_protocol), '')
-            assert(False) # should never reach here
+            assert(False)  # should never reach here
 
         for display_protocol, assert_method in [['wayland', self.assertTrue], ['donotexist', self.assertFalse]]:
             with mock.patch('bleachbit.General.run_external') as mock_run_external:
                 mock_run_external.side_effect = side_effect_func
-                is_wayland = is_linux_display_protocol_wayland()
+                is_wayland = is_unix_display_protocol_wayland()
+                assert mock_run_external.called
             self.assertIsInstance(is_wayland, bool)
             assert_method(is_wayland)
 
+        with mock.patch('bleachbit.General.run_external') as mock_run_external:
+            mock_run_external.side_effect = FileNotFoundError('not found')
+            self.assertFalse(is_unix_display_protocol_wayland())
+            assert mock_run_external.called
+
+        with mock.patch('bleachbit.General.run_external') as mock_run_external:
+            mock_run_external.side_effect = lambda a: (1, None, None)
+            self.assertFalse(is_unix_display_protocol_wayland())
+            assert mock_run_external.called
+
+        with mock.patch('bleachbit.General.run_external') as mock_run_external:
+            mock_run_external.side_effect = lambda a: (
+                0, 'test of invalid output from loginctl', None)
+            self.assertFalse(is_unix_display_protocol_wayland())
+            assert mock_run_external.called
+
     @common.skipIfWindows
     def test_xhost_autorized_root(self):
         error_code = None
+
         def side_effect_func(*args, **kwargs):
             self.assertEqual(args[0][0], 'xhost')
             return (error_code,
