@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2021 Andrew Ziem
+# Copyright (C) 2008-2024 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,8 +25,30 @@ Test case for module Windows
 
 from tests import common
 
+from bleachbit import FileUtilities, General
 from bleachbit.FileUtilities import extended_path, extended_path_undo
-from bleachbit.Windows import *
+from bleachbit.Windows import (
+    delete_locked_file,
+    delete_registry_key,
+    delete_registry_value,
+    detect_registry_key,
+    empty_recycle_bin,
+    get_clipboard_paths,
+    get_fixed_drives,
+    get_font_conf_file,
+    get_known_folder_path,
+    get_recycle_bin,
+    get_windows_version,
+    is_junction,
+    is_process_running,
+    move_to_recycle_bin,
+    parse_windows_build,
+    path_on_network,
+    set_environ,
+    setup_environment,
+    shell_change_notify,
+    split_registry_key
+)
 from bleachbit import logger
 
 import os
@@ -39,6 +61,8 @@ import mock
 from decimal import Decimal
 
 if 'win32' == sys.platform:
+    import pywintypes
+    import win32api
     import winreg
     from win32com.shell import shell
 
@@ -312,6 +336,12 @@ class WindowsTestCase(common.BleachbitTestCase):
         for path in paths:
             self.assertExists(path)
 
+    def test_get_font_conf_file(self):
+        """Unit test for get_font_conf_file"""
+        # This tests only one of three situations.
+        font_fn = get_font_conf_file()
+        self.assertExists(font_fn)
+
     def test_get_known_folder_path(self):
         """Unit test for get_known_folder_path"""
         ret = get_known_folder_path('LocalAppDataLow')
